---
title: 테스트 연동
category: 포트원 이용절차 (온보딩 가이드) > 결제 연동 > 테스트 연동
seo:
  title: 테스트 연동
  description: >-
    포트원 이용절차 중 테스트연동에 관련된 안내입니다. 결제대행사와 계약을 맺기 전에 미리 연동 테스트를 하실 수 있습니다. 테스트 연동의
    특징 및 필요한 이유를 확인해보세요.
  keywords:
    - 테스트 연동
tags:
  - 공통
  - 테스트 연동
pgCompanies:
  - 공통
searchTags:
  - 이용절차
  - 테스트채널
  - 테스트 모드
  - 테스트 연동
---

![](</uploads/포트원-이용절차/테스트-연동/Frame 427320150.png>)

<Callout title="" content="결제대행사와 계약을 맺기 전 미리 연동 테스트를 해볼 수 있습니다." />

### **테스트연동이 필요한 이유**

테스트 연동은 결제대행사와 실제 계약을 맺기 전에 미리 개발 테스트가 가능하도록 제공하는 연동 서비스입니다.\
결제대행사를 선택하기 전 어떤 결제대행사의 서비스가 잘 맞는지, 결제 흐름이 원활한지 등등 여러 가지 기준을 통해 검토해 보실 수 있습니다.
또는 결제대행사는 결정했으나 아직 계약이 진행 중일 때 운영하시는 서비스의 로직을 먼저 개발하는데 사용할 수 있습니다.

### **테스트연동의 특징**

**테스트 결제는 자동 환불됩니다.**

<Indent level="1">

결제대행사에서 제공하는 테스트용 채널 연동 정보는 직접 취소하지 않으셔도 매입 전 일괄로 취소됩니다. 30분\~1시간 간격으로 취소되거나, 당일 자정 경에 매입 전 취소됩니다. (결제대행사별 취소 시각 상이)

- 예외 케이스
  - 허브형 간편결제의 경우 실제 출금까지 이루어지니 반드시 환불을 진행해야 합니다.
  - 나이스페이먼츠의 경우 부분 취소 시 취소 금액이 자동 환불이 되지 않으니 부분 환불은 지양해 주세요. 만약, 부분 환불 테스트를 진행하신 경우 직접 전체 취소를 해야 합니다.

</Indent>

**포트원 관리자콘솔의 결제 건은 '결제완료' 상태로 그대로 남습니다**.

<Indent level="1">

테스트 결제 건이 자동 환불 처리된 경우 관리자콘솔 내 거래 내역에 상태가 반영되지 않으며, 결제 취소를 시도할 경우 '기 취소 거래' 등의 오류가 발생합니다.\
실 운영 환경에서는 취소된 거래 건의 경우 결제 상태가 정상 동기화됩니다.

</Indent>

**테스트 결제는 실제 출금이 되지 않는 케이스도 있습니다.**

<Indent level="1">

테스트 결제는 실제 출금이 되지 않기도 합니다. 일부 결제대행사는 테스트용 채널 연동 정보로 결제를 진행하는 경우 실제 출금/승인 자체가 이루어지지 않습니다.
실제 출금되지 않기 때문에 자동 환불 프로세스는 진행되지 않습니다.
이로 인해 잔액부족 등과 같은 예외 케이스에 대해 로직을 구현하고자 하는 경우 추후 결제대행사와의 계약이 완료된 이후 실 운영 연동 정보로 구현 및 테스트해야 합니다.

</Indent>

**일부 카드사는 테스트 결제가 불가합니다.**

<Indent level="1">

KB국민카드, NH농협카드, 카카오뱅크(국민 계열)은 테스트 환경에서 결제가 불가한 경우가 많습니다. \
결제대행사별로 테스트 환경에서 가능한 카드사의 기준은 다소 상이할 수 있으나, 대개 위 카드사는 테스트 \
결제가 제한됩니다. 해당 카드사로 결제가 실패하는 경우 다른 카드사로 시도하시길 권장 드립니다.

</Indent>

**가상계좌는 환불 테스트가 불가합니다.**

<Indent level="1">

가상계좌는 계좌번호 발급(채번)까지만  테스트 가능하며 실제로 입금 및 환불이 불가합니다. 실제 입금을 하셨어도 결제완료(paid)로 상태값이 변경되지 않으며 포트원에서 고객사로 웹훅이 발송되지 않습니다.
또한 환불 처리도 불가하므로 최대한 입금을 지양하여 주시기 바랍니다.

</Indent>

### **테스트연동 채널설정 방법**

포트원 관리자콘솔 안에서 테스트용 채널을 추가할 수 있습니다.\
테스트 연동을 위해 별도 가입신청 절차 없이 단순 채널 추가만으로 이용 가능합니다. 다만, 결제대행사에 따라 가입신청이 반드시 선행되어야 하는 경우가 있으니 이 점 양해 부탁드립니다.\
아래 가이드를 통해 원하시는 결제대행사의 테스트채널 설정방법을 확인해보세요.

<Callout title="결제대행사별 채널 설정방법 보러가기↗" content=" " icon="" />
